# oak9 Tython Python SDK

## Requirements

Python 3.11+

## Getting Started

1. Install the appropriate python packages locally

```sh
pip install -r requirements.txt
```

2. Call the runner with arguments

```sh
python runner.py example_configuration_file
```

### Building
1. Make sure you have installed the appropriate python packages locally (requirements.txt)
3. On the root of the repository execute:

```sh
./python/build_py_runner.sh
```

### Note:
In case that the developer wants to test the package before making it public, it is possible to install locally using pip with this command:

```sh
pip install /d/git/oak9.sac.fw/py/package
```